Uses of Class
software.amazon.awssdk.http.apache5.ProxyConfiguration
-
Packages that use ProxyConfiguration Package Description software.amazon.awssdk.http.apache5 software.amazon.awssdk.http.apache5.internal software.amazon.awssdk.http.apache5.internal.utils -
-
Uses of ProxyConfiguration in software.amazon.awssdk.http.apache5
Methods in software.amazon.awssdk.http.apache5 with parameters of type ProxyConfiguration Modifier and Type Method Description Apache5HttpClient.BuilderApache5HttpClient.Builder. proxyConfiguration(ProxyConfiguration proxyConfiguration)Configuration that defines how to communicate via an HTTP proxy. -
Uses of ProxyConfiguration in software.amazon.awssdk.http.apache5.internal
Methods in software.amazon.awssdk.http.apache5.internal that return ProxyConfiguration Modifier and Type Method Description ProxyConfigurationApache5HttpRequestConfig. proxyConfiguration()Methods in software.amazon.awssdk.http.apache5.internal with parameters of type ProxyConfiguration Modifier and Type Method Description Apache5HttpRequestConfig.BuilderApache5HttpRequestConfig.Builder. proxyConfiguration(ProxyConfiguration proxyConfiguration) -
Uses of ProxyConfiguration in software.amazon.awssdk.http.apache5.internal.utils
Methods in software.amazon.awssdk.http.apache5.internal.utils with parameters of type ProxyConfiguration Modifier and Type Method Description static org.apache.hc.client5.http.protocol.HttpClientContextApache5Utils. newClientContext(ProxyConfiguration proxyConfiguration)Returns a new HttpClientContext used for request execution.static org.apache.hc.client5.http.auth.CredentialsProviderApache5Utils. newProxyCredentialsProvider(ProxyConfiguration proxyConfiguration)Returns a new Credentials Provider for use with proxy authentication.static org.apache.hc.client5.http.auth.UsernamePasswordCredentialsApache5Utils. usernamePasswordCredentials(ProxyConfiguration proxyConfiguration)
-